==> haskell-heapsize-0.3.0.1-163-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heapsize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heapsize
version:              0.3.0.1
visibility:           public
id:                   heapsize-0.3.0.1-Fafk0VTDuDFI88nMDSThCv
key:                  heapsize-0.3.0.1-Fafk0VTDuDFI88nMDSThCv
license:              BSD-3-Clause
copyright:
    Dennis Felsing 2012-2019, Michail Pardalos 2020, Pepe Iborra 2020-2021

maintainer:           Pepe Iborra <pepeiborra@gmail.com>
author:               Michail Pardalos <mpardalos@gmail.com>
synopsis:             Determine the size of runtime data structures
description:
    heapsize is a tool to determine the size data structures.
    Determining the size of recursive data structures is
    supported. All sizes are in Bytes.

category:             GHC, Debug, Development
abi:                  c6afd0519ef9b64f8bd7ea7a98e57c68
exposed:              True
exposed-modules:      HeapSize
import-dirs:          /usr/lib/ghc-9.0.2/site-local/heapsize-0.3.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/heapsize-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-heapsize
hs-libraries:         HSheapsize-0.3.0.1-Fafk0VTDuDFI88nMDSThCv
depends:
    base-4.15.1.0 deepseq-1.4.5.0 exceptions-0.10.4 ghc-heap-9.0.2
    hashable-1.4.1.0-AcdXFBpn7hj19WgkTwKwuf
    hashtables-1.3.1-BO63nHwKuK5KrlnMU6QLie
    primitive-0.7.4.0-A5hJyO7gfJjKCazGezxOm3 transformers-0.5.6.2
    unordered-containers-0.2.19.1-AupS6pw9cGS61feF3nE08

haddock-interfaces:   /usr/share/doc/haskell-heapsize/html/heapsize.haddock
haddock-html:         /usr/share/doc/haskell-heapsize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-heapsize-0.3.0.1-181-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heapsize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heapsize
version:              0.3.0.1
visibility:           public
id:                   heapsize-0.3.0.1-4gOVcgOUiueFGEG8pt89Kg
key:                  heapsize-0.3.0.1-4gOVcgOUiueFGEG8pt89Kg
license:              BSD-3-Clause
copyright:
    Dennis Felsing 2012-2019, Michail Pardalos 2020, Pepe Iborra 2020-2021

maintainer:           Pepe Iborra <pepeiborra@gmail.com>
author:               Michail Pardalos <mpardalos@gmail.com>
synopsis:             Determine the size of runtime data structures
description:
    heapsize is a tool to determine the size data structures.
    Determining the size of recursive data structures is
    supported. All sizes are in Bytes.

category:             GHC, Debug, Development
abi:                  ced46d3118becf6abd882b6e29b7de4b
exposed:              True
exposed-modules:      HeapSize
import-dirs:          /usr/lib/ghc-9.0.2/site-local/heapsize-0.3.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/heapsize-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-heapsize
hs-libraries:         HSheapsize-0.3.0.1-4gOVcgOUiueFGEG8pt89Kg
depends:
    base-4.15.1.0 deepseq-1.4.5.0 exceptions-0.10.4 ghc-heap-9.0.2
    hashable-1.4.2.0-ACOKJtOF9viKWyhESTEaY8
    hashtables-1.3.1-Ckuc0N1pVjVEsnuH3oQywx
    primitive-0.7.4.0-GEmDUJD22mHBwXDxBmNo7T transformers-0.5.6.2
    unordered-containers-0.2.19.1-KAeBL5aytSRB39idbhEXBI

haddock-interfaces:   /usr/share/doc/haskell-heapsize/html/heapsize.haddock
haddock-html:         /usr/share/doc/haskell-heapsize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
